Pokedex API Wrapper Library
===========================

A wrapper library for the `Pokedex API`_. Get all your Pokemon Needs in
one place.

|GitHub release| |license| |Say Thanks!|

Installation
------------

This is a `Python`_ module available through the `PyPI`_.

Before installing, `download and install Python`_. We recommend
installing version 3.5+ of Python.

Installation is done using the ``pip install`` command:

.. code:: bash

    $ pip install pokedex.py

For more info, see `pip install`_ docs.

Get Started
-----------

Read the `Wiki`_ to see the available classes and methods (with
examples) and know how to use them.

Pokedex API
-----------

-  `Official Website and Documentation`_
-  `GitHub Organization`_ for other libraries
-  `Discord`_ for support and discussion

Contributors
------------

The developer of the `Pokedex API`_ and this wrapper library is
`k3rn31p4nic`_

`List of all contributors`_

Donate
------

| If want to support the development of this project to keep this alive
  forever, you can send donations to the developers.
| Your donations will ensure the development of this project and I’ll
  make sure this project stays active forever. You can donate via
  `PayPal`_.

License
-------

`GPL-3.0`_

    If you liked this project you can **⭐ Star** it on `GitHub`_ to show
    your love.

.. _Pokedex API: https://pokedevs.bastionbot.org
.. _Python: https://python.org
.. _PyPI: https://pypi.python.org/
.. _download and install Python: https://www.python.org/downloads/
.. _pip install: https://docs.python.org/3/installing/index.html
.. _Wiki: https://github.com/PokeDevs/pokedex.py/wiki
.. _Official Website and Documentation: https://pokedevs.bastionbot.org
.. _GitHub Organization: https://github.com/PokeDevs
.. _Discord: https://discord.gg/7P4H3TY
.. _k3rn31p4nic: https://sankarsankampa.com
.. _List of all contributors: https://github.com/PokeDevs/pokedex.py/graphs/contributors
.. _PayPal: https://paypal.me/snkrsnkampa
.. _GPL-3.0: https://github.com/PokeDevs/pokedex.py/blob/master/LICENSE.txt
.. _GitHub: https://github.com/PokeDevs/pokedex.py

.. |GitHub release| image:: https://img.shields.io/github/release/PokeDevs/pokedex.py.svg?style=flat
   :target: https://github.com/PokeDevs/pokedex.py/releases
.. |license| image:: https://img.shields.io/github/license/PokeDevs/pokedex.py.svg
   :target: LICENSE
.. |Say Thanks!| image:: https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg
   :target: https://saythanks.io/to/k3rn31p4nic
